@@ -11,20 +11,17 @@ public:
     void setName(QString);
     void setUrl(QString);
     void setGenre(QString);
-    void setLanguage(QString);
     void setCountry(QString);
 
     QString getName();
     QString getUrl();
     QString getGenre();
-    QString getLanguage();
     QString getCountry();
 
 private:
     QString name;
     QString url;
     QString genre;
-    QString language;
     QString country;
 
 
